@@ -1,10 +1,10 @@
 import os
-from conftest import ANY, pytest
-from requests_mock import ANY
-
+import logging
 from octodns.provider.yaml import YamlProvider
 from octodns.zone import Zone
 
+logging.basicConfig()
+
 
 def test_zone_data(provider, zone_name):
     expected = Zone(zone_name, [])
@@ -12,7 +12,6 @@ def test_zone_data(provider, zone_name):
     source.populate(expected)
     zone = Zone(zone_name, [])
     provider.populate(zone)
-    assert len(zone.records) == 3
-    changes = expected.changes(zone, provider)
+    assert len(zone.records) == 5
     plan = provider.plan(expected)
     provider.apply(plan)
